==> recog-client-api-0.0.7-20201123.073631-9-sources.jar: com/xforceplus/phoenix/recog/api/RecFileApi.java <==
package com.xforceplus.phoenix.recog.api;

import com.xforceplus.phoenix.recog.api.model.MsRecResponse;
import com.xforceplus.phoenix.recog.api.model.file.*;
import com.xforceplus.phoenix.recog.api.model.invoice.MsDownLoadRequest;
import com.xforceplus.phoenix.recog.api.model.invoice.MsDownLoadResponse;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import java.io.IOException;
import java.util.List;

/**
 * @author chong
 */
public interface RecFileApi {
    /**
     * 新文件上传
     *
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "扫描文件上传", notes = "扫描文件上传", response = MsFileUploadResponse.class, tags = {"recFileApi"})
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFileUploadResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/uploadFile",
            produces = {"application/json"},
            method = RequestMethod.POST)
    MsFileUploadResponse uploadFile(@ApiParam @RequestBody MsFileUploadRequest request);

    /**
     * 新文件上传
     *
     * @param
     * @return
     */
    @ApiOperation(value = "扫描文件上传U", notes = "扫描文件上传U", response = MsFileUploadResponse.class, tags = {"recFileApi"})
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFileUploadResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/uploadFileU",
            produces = {"application/json"},
            method = RequestMethod.POST)
    MsFileUploadResponse uploadFileU(@ApiParam @RequestBody MsFileUploadRequestU msFileUploadRequestU) throws IOException;


    @ApiOperation(value = "文件层级调整", notes = "文件层级调整", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})

    /**
     * 文件层级调整
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/reGenerateHierarchy", method = RequestMethod.POST)
    MsRecResponse reGenerateHierarchy(@ApiParam(name = "文件层级调整请求参数", value = "json格式", required = true)
                                      @RequestBody MsReGenerateHierarchyRequest request);

    @ApiOperation(value = "取消挂接", notes = "取消挂接", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "PUT", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})

    /**
     * 取消挂接
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/cancel-hook", method = RequestMethod.PUT)
    MsRecResponse cancelHook(@ApiParam(name = "取消挂接参数", value = "json格式", required = true)
                             @RequestBody MsCancelHookRequest request);

    /**
     * 查询待提交文件
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查询待提交文件", notes = "查询待提交文件", response = MsFindUnSubmitFilesResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFindUnSubmitFilesResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findUnSubmitFiles", method = RequestMethod.POST)
    MsFindUnSubmitFilesResponse findUnSubmitFiles(@ApiParam(name = "查询待提交文件请求参数", value = "json格式", required = true)
                                                  @RequestBody MsFindUnSubmitFilesRequest request);


    /**
     * 查询已提交文件
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查询已提交文件", notes = "查询已提交文件", response = MsFindSubmittedFilesResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFindSubmittedFilesResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findSubmittedFiles", method = RequestMethod.POST)
    MsFindSubmittedFilesResponse findSubmittedFiles(@ApiParam(name = "查询已提交文件请求参数", value = "json格式", required = true)
                                                    @RequestBody MsFindSubmittedFilesRequest request);


    @ApiOperation(value = "查找文件", notes = "查找文件", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 查找文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findFile", method = RequestMethod.POST)
    MsRecResponse<List<FileInfoDto>> findFile(@ApiParam(name = "", value = "json格式", required = true) @RequestBody MsFindFileRequest request);


    @ApiOperation(value = "查找发票文件（发票管理特定服务）", notes = "查找发票文件（发票管理特定服务）",
            response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 查找发票文件（发票管理特定服务）
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findPimInvoiceFile", method = RequestMethod.POST)
    MsRecResponse<MsRecogPimInvoiceFileInfo> findPimInvoiceFile(@ApiParam(name = "", value = "json格式", required = true)
                                                                @RequestBody MsFindPimInvoiceFileRequest request);


    @ApiOperation(value = "删除文件", notes = "删除文件", response = MsFileDeleteResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsFileDeleteResponse.class)})
    /**
     * 删除文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/deleteFile", method = RequestMethod.POST)
    MsFileDeleteResponse deleteFile(@ApiParam(name = "删除文件请求参数", value = "json格式", required = true)
                                    @RequestBody MsFileDeleteRequest request);

    @ApiOperation(value = "提交全部待提交文件", notes = "提交全部待提交文件", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 提交全部待提交文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/submit", method = RequestMethod.POST)
    MsRecResponse<?> submit(@ApiParam(name = "文件提交请求参数", value = "json格式", required = true)
                            @RequestBody MsSubmitRequest request);


    @ApiOperation(value = "拉取提交结果Job", notes = "拉取提交结果Job", tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回")})
    /**
     * 拉取提交结果Job
     *
     * @param
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/fetchSubmitResultJob", method = RequestMethod.POST)
    void fetchSubmitResultJob();


    @ApiOperation(value = "文件统计信息", notes = "文件统计信息", response = MsFindStatResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsFindStatResponse.class)})
    /**
     *
     *文件统计信息
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findStat", method = RequestMethod.POST)
    MsFindStatResponse findStat(@ApiParam @RequestBody MsFindStatRequest request);

    /**
     * @param request
     * @return
     */
    @ApiOperation(value = "查询提交处理情况", notes = "查询提交处理情况", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/submitProcess", method = RequestMethod.POST)
    MsRecResponse<SubmitProcessDto> submitProcess(@ApiParam @RequestBody MsSubmitProcessRequest request);


    /**
     * 下载文件列表
     *
     * @param request
     * @return
     */

    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/downLoadFiles", method = RequestMethod.POST)
    MsDownLoadResponse downLoadFiles(@ApiParam @RequestBody MsDownLoadRequest request);

    /**
     * 轮询redis查询待提交文件
     *
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findUnSubmitFilesByRedis", method = RequestMethod.POST)
    MsFindUnSubmitFilesResponse findUnSubmitFilesByRedis(@ApiParam(name = "轮询redis查询待提交文件请求参数", value = "json格式", required = true)
                                                         @RequestBody MsFindUnSubmitFilesRequest request);

    /**
     * 查找发票文件集合（发票管理特定服务）
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查找发票文件集合（发票管理特定服务）", notes = "查找发票文件集合（发票管理特定服务）",
            response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findPimInvoiceFileList", method = RequestMethod.POST)
    MsRecResponse<List<MsRecogPimInvoiceFileInfo>> findPimInvoiceFileList(@ApiParam(name = "", value = "json格式", required = true)
                                                                          @RequestBody MsFindPimInvoiceFileRequest request);

    /**
     * 校验数据权限
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "校验数据权限", notes = "校验数据权限）",
            response = MsGetDataPermissionResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsGetDataPermissionResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/getDataPermission", method = RequestMethod.POST)
    MsGetDataPermissionResponse getDataPermission(@ApiParam(name = "", value = "json格式", required = true)
                                                  @RequestBody MsGetDataPermissionRequest request);

}

==> recog-client-api-0.0.7-20210302.054058-22-sources.jar: com/xforceplus/phoenix/recog/api/RecFileApi.java <==
package com.xforceplus.phoenix.recog.api;

import com.xforceplus.phoenix.recog.api.model.MsRecResponse;
import com.xforceplus.phoenix.recog.api.model.file.*;
import com.xforceplus.phoenix.recog.api.model.invoice.MsDownLoadRequest;
import com.xforceplus.phoenix.recog.api.model.invoice.MsDownLoadResponse;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import java.io.IOException;
import java.util.List;

/**
 * @author chong
 */
public interface RecFileApi {
    /**
     * 新文件上传
     *
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "扫描文件上传", notes = "扫描文件上传", response = MsFileUploadResponse.class, tags = {"recFileApi"})
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFileUploadResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/uploadFile",
            produces = {"application/json"},
            method = RequestMethod.POST)
    MsFileUploadResponse uploadFile(@ApiParam @RequestBody MsFileUploadRequest request);

    /**
     * 新文件上传
     *
     * @param
     * @return
     */
    @ApiOperation(value = "扫描文件上传U", notes = "扫描文件上传U", response = MsFileUploadResponse.class, tags = {"recFileApi"})
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFileUploadResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/uploadFileU",
            produces = {"application/json"},
            method = RequestMethod.POST)
    MsFileUploadResponse uploadFileU(@ApiParam @RequestBody MsFileUploadRequestU msFileUploadRequestU) throws IOException;


    @ApiOperation(value = "文件层级调整", notes = "文件层级调整", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})

    /**
     * 文件层级调整
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/reGenerateHierarchy", method = RequestMethod.POST)
    MsRecResponse reGenerateHierarchy(@ApiParam(name = "文件层级调整请求参数", value = "json格式", required = true)
                                      @RequestBody MsReGenerateHierarchyRequest request);

    @ApiOperation(value = "取消挂接", notes = "取消挂接", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "PUT", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})

    /**
     * 取消挂接
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/cancel-hook", method = RequestMethod.PUT)
    MsRecResponse cancelHook(@ApiParam(name = "取消挂接参数", value = "json格式", required = true)
                             @RequestBody MsCancelHookRequest request);

    /**
     * 查询待提交文件
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查询待提交文件", notes = "查询待提交文件", response = MsFindUnSubmitFilesResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFindUnSubmitFilesResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findUnSubmitFiles", method = RequestMethod.POST)
    MsFindUnSubmitFilesResponse findUnSubmitFiles(@ApiParam(name = "查询待提交文件请求参数", value = "json格式", required = true)
                                                  @RequestBody MsFindUnSubmitFilesRequest request);


    /**
     * 查询已提交文件
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查询已提交文件", notes = "查询已提交文件", response = MsFindSubmittedFilesResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsFindSubmittedFilesResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findSubmittedFiles", method = RequestMethod.POST)
    MsFindSubmittedFilesResponse findSubmittedFiles(@ApiParam(name = "查询已提交文件请求参数", value = "json格式", required = true)
                                                    @RequestBody MsFindSubmittedFilesRequest request);


    @ApiOperation(value = "查找文件", notes = "查找文件", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 查找文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findFile", method = RequestMethod.POST)
    MsRecResponse<List<FileInfoDto>> findFile(@ApiParam(name = "", value = "json格式", required = true) @RequestBody MsFindFileRequest request);


    @ApiOperation(value = "查找发票文件（发票管理特定服务）", notes = "查找发票文件（发票管理特定服务）",
            response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 查找发票文件（发票管理特定服务）
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findPimInvoiceFile", method = RequestMethod.POST)
    MsRecResponse<MsRecogPimInvoiceFileInfo> findPimInvoiceFile(@ApiParam(name = "", value = "json格式", required = true)
                                                                @RequestBody MsFindPimInvoiceFileRequest request);


    @ApiOperation(value = "删除文件", notes = "删除文件", response = MsFileDeleteResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsFileDeleteResponse.class)})
    /**
     * 删除文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/deleteFile", method = RequestMethod.POST)
    MsFileDeleteResponse deleteFile(@ApiParam(name = "删除文件请求参数", value = "json格式", required = true)
                                    @RequestBody MsFileDeleteRequest request);

    @ApiOperation(value = "提交全部待提交文件", notes = "提交全部待提交文件", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    /**
     * 提交全部待提交文件
     *
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/submit", method = RequestMethod.POST)
    MsRecResponse<?> submit(@ApiParam(name = "文件提交请求参数", value = "json格式", required = true)
                            @RequestBody MsSubmitRequest request);


    @ApiOperation(value = "拉取提交结果Job", notes = "拉取提交结果Job", tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回")})
    /**
     * 拉取提交结果Job
     *
     * @param
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/fetchSubmitResultJob", method = RequestMethod.POST)
    void fetchSubmitResultJob();


    @ApiOperation(value = "文件统计信息", notes = "文件统计信息", response = MsFindStatResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsFindStatResponse.class)})
    /**
     *
     *文件统计信息
     * @param request
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findStat", method = RequestMethod.POST)
    MsFindStatResponse findStat(@ApiParam @RequestBody MsFindStatRequest request);

    /**
     * @param request
     * @return
     */
    @ApiOperation(value = "查询提交处理情况", notes = "查询提交处理情况", response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {@ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/submitProcess", method = RequestMethod.POST)
    MsRecResponse<SubmitProcessDto> submitProcess(@ApiParam @RequestBody MsSubmitProcessRequest request);


    /**
     * 下载文件列表
     *
     * @param request
     * @return
     */

    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/downLoadFiles", method = RequestMethod.POST)
    MsDownLoadResponse downLoadFiles(@ApiParam @RequestBody MsDownLoadRequest request);

    /**
     * 轮询redis查询待提交文件
     *
     * @return
     */
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findUnSubmitFilesByRedis", method = RequestMethod.POST)
    MsFindUnSubmitFilesResponse findUnSubmitFilesByRedis(@ApiParam(name = "轮询redis查询待提交文件请求参数", value = "json格式", required = true)
                                                         @RequestBody MsFindUnSubmitFilesRequest request);

    /**
     * 查找发票文件集合（发票管理特定服务）
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "查找发票文件集合（发票管理特定服务）", notes = "查找发票文件集合（发票管理特定服务）",
            response = MsRecResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsRecResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/findPimInvoiceFileList", method = RequestMethod.POST)
    MsRecResponse<List<MsRecogPimInvoiceFileInfo>> findPimInvoiceFileList(@ApiParam(name = "", value = "json格式", required = true)
                                                                          @RequestBody MsFindPimInvoiceFileRequest request);

    /**
     * 校验数据权限
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "校验数据权限", notes = "校验数据权限）",
            response = MsGetDataPermissionResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsGetDataPermissionResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/getDataPermission", method = RequestMethod.POST)
    MsGetDataPermissionResponse getDataPermission(@ApiParam(name = "", value = "json格式", required = true)
                                                  @RequestBody MsGetDataPermissionRequest request);


    /**
     * 影像导出
     *
     * @param request
     * @return
     */
    @ApiOperation(value = "影像导出", notes = "影像导出）",
            response = MsExportResponse.class, tags = {"recFileApi"}, httpMethod = "POST", produces = MediaType.APPLICATION_JSON_UTF8_VALUE)
    @ApiResponses(value = {
            @ApiResponse(code = 200, message = "统一返回", response = MsExportResponse.class)})
    @RequestMapping(value = "/ms/api/v1/recog/recFileApi/exportFile", method = RequestMethod.POST)
    MsExportResponse exportFile(@ApiParam(name = "", value = "json格式", required = true)
                                @RequestBody MsExportRequest request);

}
